@@ -95,8 +95,35 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAIAgentCall(self, request):
+        """用于调用AI模型发起外呼通话，仅限自有电话号码使用，目前开通高级版座席**限时**免费体验。
+
+        发起通话前，请先确认您的AI模型是否兼容 OpenAI、Azure 或 Minimax 协议，并前往模型服务商网站获取相关鉴权信息。 具体功能说明请参考文档 [腾讯云联络中心AI通话平台](https://cloud.tencent.com/document/product/679/112100)。
+
+        :param request: Request instance for CreateAIAgentCall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAIAgentCall", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAIAgentCallResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAICall(self, request):
-        """创建ai外呼会话(仅支持高级版座席)
+        """用于调用AI模型发起外呼通话，仅限自有电话号码使用，目前开通高级版座席**限时**免费体验。
+
+        发起通话前，请先确认您的AI模型是否兼容 OpenAI、Azure 或 Minimax 协议，并前往模型服务商网站获取相关鉴权信息。 具体功能说明请参考文档 [腾讯云联络中心AI通话平台](https://cloud.tencent.com/document/product/679/112100)。
 
         :param request: Request instance for CreateAICall.
         :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAICallRequest`
@@ -302,6 +329,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOwnNumberApply(self, request):
+        """创建客户自携号码接入审核
+
+        :param request: Request instance for CreateOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePredictiveDialingCampaign(self, request):
         """创建预测式外呼任务
 
@@ -463,6 +513,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAICallExtractResult(self, request):
+        """获取 AI 通话内容提取结果。
+
+        :param request: Request instance for DescribeAICallExtractResult.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAICallExtractResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAICallExtractResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeActiveCarrierPrivilegeNumber(self, request):
         """查询生效运营商白名单规则
 
@@ -1017,6 +1090,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTelRecordAsr(self, request):
+        """拉取会话录音转文本信息
+
+        :param request: Request instance for DescribeTelRecordAsr.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTelRecordAsr", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTelRecordAsrResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTelSession(self, request):
         """获取 PSTN 会话信息
 
@@ -1132,6 +1228,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyOwnNumberApply(self, request):
+        """修改客户自携号码审批单
+
+        :param request: Request instance for ModifyOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyStaff(self, request):
         """修改客服账号
 
